@@ -15,8 +15,9 @@ use English qw/ -no_match_vars /;
 use base qw/VCS::Which::Plugin/;
 use Path::Class;
 use File::chdir;
+use Contextual::Return;
 
-our $VERSION = version->new('0.1.0');
+our $VERSION = version->new('0.1.1');
 our $name    = 'Bazaar';
 our $exe     = 'bzr';
 our $meta    = '.bzr';
@@ -85,7 +86,7 @@ sub pull {
 	croak "'$dir' is not a directory!" if !-e $dir;
 
 	local $CWD = $dir;
-	return !system '$exe pull';
+	return !system "$exe pull";
 }
 
 sub cat {
@@ -112,26 +113,29 @@ sub log {
 	return
 		SCALAR   { `$exe log $args` }
 		ARRAYREF { `$exe log $args` }
-#		HASHREF  {
-#			my $logs = `$exe log $args`;
-#			my @logs = split /^-+\n/xms, $logs;
-#			shift @logs;
-#			my $num = @logs;
-#			my %log;
-#			for my $log (@logs) {
-#				my ($details, $description) = split /\n\n?/, $log, 2;
-#				$details =~ s/^\s*(.*?)\s*/$1/;
-#				my @details = split /\s+\|\s+/, $details;
-#				$details[0] =~ s/^r//;
-#				$log{$num--} = {
-#					rev    => $details[0],
-#					Author => $details[1],
-#					Date   => $details[2],
-#					description => $description,
-#				},
-#			}
-#			return \%log;
-#		}
+		HASHREF  {
+			my $logs = `$exe log $args`;
+			my @logs = split /^-+\n/xms, $logs;
+			shift @logs;
+			my $num = @logs;
+			my %log;
+			for my $log (@logs) {
+				next if $log =~ /--include-merges/;
+				my ($details, $description) = $log =~ /^(.*)\nmessage:\s*(.*)$/xms;
+				if (!defined $details) {
+					warn "Error in reading line:\n$log\n";
+					next;
+				}
+				my %details = map {split /:\s+/, $_, 2} split /\n/, $details, 5;
+				$log{$num--} = {
+					rev    => $details{revno},
+					Author => $details{committer},
+					Date   => $details{timestamp},
+					description => $description,
+				},
+			}
+			return \%log;
+		}
 }
 
 1;
@@ -144,7 +148,7 @@ VCS::Which::Plugin::Bazaar - The Bazaar plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Bazaar version 0.1.0.
+This documentation refers to VCS::Which::Plugin::Bazaar version 0.1.1.
 
 =head1 SYNOPSIS
 
